#!/bin/bash

TARGETDIR="/boot"
EXECUSER="$USER"

PROGNAME=$(basename $0)

Usage="$PROGNAME [-d|--directory ZipDirectory] [NoraExternalConnectorArguments...]"

declare -a param=()

for OPT in "$@"
do
    case "$OPT" in
        '-h'|'--help' )
            echo "$Usage"
            exit 1
            ;;
        '-d'|'--directory' )
            if [[ -z "$2" ]] || [[ "$2" =~ ^-+ ]]; then
                echo "$PROGNAME: option requires an argument -- $1" 1>&2
                exit 1
            fi
            TARGETDIR="$2"
            shift 2
            ;;
        '--'|'-' )
            shift 1
            param+=( "$@" )
            break
            ;;
        -*)
            param+=( "$1" )
            shift 1
            ;;
        *)
            if [[ ! -z "$1" ]] && [[ ! "$1" =~ ^-+ ]]; then
                param+=( "$1" )
                shift 1
            fi
            ;;
    esac
done

echo "TARGETDIR=$TARGETDIR"
echo "NORAARGUMENTS=${param[@]}"
NORAARGUMENTS="${param[@]}"


WORK_DIR=$(cd $(dirname $0);pwd)
cd $WORK_DIR

NORAZIP=`ls -1tr ${TARGETDIR}/NoraExternalConnector_v*.zip | head -1`



if [ ${NORAZIP} ]; then
    echo "Found NoraExternalConnector zip file... ${NORAZIP}"
    echo "    Start auto update...${NORAZIP}"

    sudo ./update.sh -u ${EXECUSER} ${NORAZIP}

    sudo rm -f ${NORAZIP}
fi

NORACONFIG="${TARGETDIR}/NoraExternalConnector.xml"
if [ -e $NORACONFIG ]; then
    echo "Copy config file...$NORACONFIG"

    cp -f $NORACONFIG ./config/
fi

NORAHOST="${TARGETDIR}/hosts.txt"
if [ -e $NORAHOST ]; then
    echo "Copy host file...$NORAHOST"

    cp -f $NORAHOST ./config/
fi

echo "Start NoraExternalConnector with arguments...$NORAARGUMENTS"
./start.sh ${NORAARGUMENTS}

